==> haskell-binary-instances-1.0.0.1-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 binary-instances
version:              1.0.0.1
visibility:           public
id:                   binary-instances-1.0.0.1-H198t5AI6l13ZoAe0PxR9
key:                  binary-instances-1.0.0.1-H198t5AI6l13ZoAe0PxR9
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/binary-instances#readme
synopsis:             Orphan instances for binary
description:
    `binary-instances` defines orphan instances for types in some popular packages.

category:             Web
abi:                  f0c8e8f73442d27e2107e53f01283e52
exposed:              True
exposed-modules:
    Data.Binary.Instances Data.Binary.Instances.Aeson
    Data.Binary.Instances.CaseInsensitive
    Data.Binary.Instances.Hashable Data.Binary.Instances.Scientific
    Data.Binary.Instances.Tagged Data.Binary.Instances.Text
    Data.Binary.Instances.Time
    Data.Binary.Instances.UnorderedContainers
    Data.Binary.Instances.Vector

import-dirs:          /usr/lib/ghc-8.10.2/site-local/binary-instances-1.0.0.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/binary-instances-1.0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/binary-instances-1.0.0.1
hs-libraries:         HSbinary-instances-1.0.0.1-H198t5AI6l13ZoAe0PxR9
depends:
    aeson-1.5.3.0-HJgqP6RhegPJh4mTnTi74F base-4.14.1.0 binary-0.8.8.0
    binary-orphans-1.0.1-9CppJjUdaKIGGrIGaQkVJV
    case-insensitive-1.2.1.0-JyDtjOlIWzSBSwCZsM9Mt7
    hashable-1.3.0.0-JGLlBEJENIuAu5I6ebR7jm
    scientific-0.3.6.2-7xwfjLGR8Bo21WSiT6C1fZ
    tagged-0.8.6-6ynGuqiqWewDmeFAuVgKQe text-1.2.3.2
    text-binary-0.2.1.1-Bl0n9PdHQ5w1N8gChIUmsJ
    time-compat-1.9.3-7ggu9tBZ549ArRiXul7aQt
    unordered-containers-0.2.12.0-32hypcNpCYxF7nyZEjDl6X
    vector-0.12.1.2-1NVIFdUJ04d5LWJjqOrbRq
    vector-binary-instances-0.2.5.1-20dHR2LWRQy6AXZKlJxaQb

haddock-interfaces:
    /usr/share/doc/haskell-binary-instances/html/binary-instances.haddock

haddock-html:         /usr/share/doc/haskell-binary-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-instances-1.0.0.1-43-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 binary-instances
version:              1.0.0.1
visibility:           public
id:                   binary-instances-1.0.0.1-3VZe4KVUlpIKkOLVHjur64
key:                  binary-instances-1.0.0.1-3VZe4KVUlpIKkOLVHjur64
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/binary-instances#readme
synopsis:             Orphan instances for binary
description:
    `binary-instances` defines orphan instances for types in some popular packages.

category:             Web
abi:                  5a3a036e190adeaf63e22c0b2dbbd720
exposed:              True
exposed-modules:
    Data.Binary.Instances Data.Binary.Instances.Aeson
    Data.Binary.Instances.CaseInsensitive
    Data.Binary.Instances.Hashable Data.Binary.Instances.Scientific
    Data.Binary.Instances.Tagged Data.Binary.Instances.Text
    Data.Binary.Instances.Time
    Data.Binary.Instances.UnorderedContainers
    Data.Binary.Instances.Vector

import-dirs:          /usr/lib/ghc-8.10.2/site-local/binary-instances-1.0.0.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/binary-instances-1.0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/binary-instances-1.0.0.1
hs-libraries:         HSbinary-instances-1.0.0.1-3VZe4KVUlpIKkOLVHjur64
depends:
    aeson-1.5.4.0-EKD5HdaQvhNEWBNwoih2VS base-4.14.1.0 binary-0.8.8.0
    binary-orphans-1.0.1-HNoDNwFeAqU25S8sbYxBon
    case-insensitive-1.2.1.0-ccIp1FqHF2Q6OXa5AsQK
    hashable-1.3.0.0-IhQ3DGT3Mv7KNucUf0KrvO
    scientific-0.3.6.2-7eFS4S3mXIcI1VNk1i1V3a
    tagged-0.8.6-6ynGuqiqWewDmeFAuVgKQe text-1.2.3.2
    text-binary-0.2.1.1-Bl0n9PdHQ5w1N8gChIUmsJ
    time-compat-1.9.3-HKYijktRj9PLg5DtBlQU3j
    unordered-containers-0.2.12.0-L7e0ebfosZDK7txbADKTIQ
    vector-0.12.1.2-E9lCzNvHLtkKefSxgFoNMj
    vector-binary-instances-0.2.5.1-GuPkojCVkHs12kPvUc3tF6

haddock-interfaces:
    /usr/share/doc/haskell-binary-instances/html/binary-instances.haddock

haddock-html:         /usr/share/doc/haskell-binary-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
